@@ -25,8 +25,8 @@
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = [ 'sphinx.ext.autodoc', 'sphinx.ext.todo',
-               'repoze.sphinx.autointerface' ]
+extensions = [ 'sphinx.ext.autodoc', 'sphinx.ext.todo']
+#               'repoze.sphinx.autointerface' ]
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['.templates']
