@@ -321,6 +321,42 @@ class export_image_tests(EuphorieFunctionalTestCase):
                 .startswith('http://client.euphorie.org/nl/'))
 
 
+class JsonViewTests(unittest.TestCase):
+    def JsonView(self, *a, **kw):
+        from .. import JsonView
+        return JsonView(*a, **kw)
+
+    def test_invalid_input(self):
+        import json
+        import StringIO
+        from zope.publisher.browser import TestRequest
+        request = TestRequest()
+        request.stdin = StringIO.StringIO('invalid json')
+        view = self.JsonView(None, request)
+        response = view()
+        self.assertEqual(
+                json.loads(response),
+                {'type': 'error',
+                 'message': 'Invalid JSON input'})
+
+    def test_bad_method(self):
+        import json
+        import StringIO
+        import mock
+        from zope.publisher.browser import TestRequest
+        request = TestRequest()
+        request.stdin = StringIO.StringIO()
+        context = mock.Mock()
+        context.getPhysicalPath.return_value = ['', 'Plone', 'client', 'api']
+        view = self.JsonView(context, request)
+        response = view()
+        self.assertEqual(request.response.getStatus(), 405)
+        self.assertEqual(
+                json.loads(response),
+                {'type': 'error',
+                 'message': 'HTTP method not allowed'})
+
+
 class DummySchema(Interface):
     field = Choice(vocabulary=SimpleVocabulary([
         SimpleTerm(u'foo', title=u'Bar')]))
